Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(192)

Unified Diff: content/browser/ssl/ssl_policy.h

Issue 1244863003: Attach a SecurityStyle to each request in ResourceLoader (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: unit test fixes Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/ssl/ssl_policy.h
diff --git a/content/browser/ssl/ssl_policy.h b/content/browser/ssl/ssl_policy.h
index 78dbb6d8960f59237658d3d5c032374d851b6342..8998d1ff2f0309f59693fde8196ec599525065f4 100644
--- a/content/browser/ssl/ssl_policy.h
+++ b/content/browser/ssl/ssl_policy.h
@@ -9,13 +9,17 @@
#include "base/memory/ref_counted.h"
#include "content/public/common/resource_type.h"
+#include "content/public/common/security_style.h"
+
+class GURL;
namespace content {
class NavigationEntryImpl;
class SSLCertErrorHandler;
class SSLPolicyBackend;
class SSLRequestInfo;
-class WebContentsImpl;
+class WebContents;
+struct SSLStatus;
// SSLPolicy
//
@@ -37,12 +41,17 @@ class SSLPolicy {
void OnRequestStarted(SSLRequestInfo* info);
// Update the SSL information in |entry| to match the current state.
- // |web_contents| is the WebContentsImpl associated with this entry.
- void UpdateEntry(NavigationEntryImpl* entry,
- WebContentsImpl* web_contents);
+ // |web_contents| is the WebContents associated with this entry.
+ void UpdateEntry(NavigationEntryImpl* entry, WebContents* web_contents);
SSLPolicyBackend* backend() const { return backend_; }
+ // Returns a security style describing an individual resource. Does
+ // not take into account any of the page- or host-level state such as
+ // mixed content or whether the host has run insecure content.
+ static SecurityStyle GetSecurityStyleForResource(const GURL& url,
+ const SSLStatus& ssl);
+
private:
enum OnCertErrorInternalOptionsMask {
OVERRIDABLE = 1 << 0,

Powered by Google App Engine
This is Rietveld 408576698